﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 헤더
        /// </summary>
        private string header = "Event      Key        Sys-Key    Text       Ctrl-Text  Sys-Text   Ime        KeyStates" +
                                "       IsDown     IsUp       IsToggled  IsRepeat";

        /// <summary>
        /// 키 포맷 문자열
        /// </summary>
        private string keyFormatString = "{0,-10} {1,-10} {2,-10}                                  " +
                                         "{3,-10} {4,-15} {5,-10} {6,-10} {7,-10} {8,-10}";

        /// <summary>
        /// 텍스트 포맷 문자열
        /// </summary>
        private string textFormatString = "{0,-10}                       {1,-10} {2,-10} {3,-10}";

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.headerTextBlock.Text = header;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 키 DOWN 처리하기 - OnKeyDown(e)

        /// <summary>
        /// 키 DOWN 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnKeyDown(KeyEventArgs e)
        {
            base.OnKeyDown(e);

            string message = string.Format
            (
                this.keyFormatString,
                e.RoutedEvent.Name  ,
                e.Key               ,
                e.SystemKey         ,
                e.ImeProcessedKey   ,
                e.KeyStates         ,
                e.IsDown            ,
                e.IsUp              ,
                e.IsToggled         ,
                e.IsRepeat
            );

            DisplayInformation(message);
        }

        #endregion
        #region 키 UP 처리하기 - OnKeyUp(e)

        /// <summary>
        /// 키 UP 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnKeyUp(KeyEventArgs e)
        {
            base.OnKeyUp(e);

            string message = string.Format
            (
                this.keyFormatString,
                e.RoutedEvent.Name  ,
                e.Key               ,
                e.SystemKey         ,
                e.ImeProcessedKey   ,
                e.KeyStates         ,
                e.IsDown            ,
                e.IsUp              ,
                e.IsToggled         ,
                e.IsRepeat
            );

            DisplayInformation(message);
        }

        #endregion
        #region 텍스트 입력시 처리하기 - OnTextInput(e)

        /// <summary>
        /// 텍스트 입력시 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnTextInput(TextCompositionEventArgs e)
        {
            base.OnTextInput(e);

            string message = string.Format
            (
                this.textFormatString,
                e.RoutedEvent.Name   ,
                e.Text               ,
                e.ControlText        ,
                e.SystemText
            );

            DisplayInformation(message);
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 정보 표시하기 - DisplayInformation(message)

        /// <summary>
        /// 정보 표시하기
        /// </summary>
        /// <param name="message">메시지</param>
        private void DisplayInformation(string message)
        {
            TextBlock textBlock = new TextBlock();

            textBlock.Text = message;

            this.outputStackPanel.Children.Add(textBlock);

            this.scrollViewer.ScrollToBottom();
        }

        #endregion
    }
}